/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */

package com.sun.jini.admin;

import java.rmi.RemoteException;
import java.io.IOException;

/**
 * Admin interface for controlling the location of a service's persistent
 * storage.  Administrable services are encouraged to have their admin
 * object implement this interface.
 *
 * @see net.jini.admin.Administrable#getAdmin
 */
public interface StorageLocationAdmin {
    /**
     * Returns the location of the service's persistent storage.
     * Typically returns a directory pathname unless the service
     * specifies otherwise.
     */
    String getStorageLocation() throws RemoteException;

    /**
     * Sets the location of the service's persistent storage,
     * moving all current persistent storage from the current
     * location to the specified new location.
     *
     * @exception IOException if moving the persistent storage fails
     */
    void setStorageLocation(String location)
	throws IOException, RemoteException;
}
