/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.example.service;

import java.io.*;
import java.lang.*;
import java.io.IOException;
import com.sun.jini.system.FileSystem;
import com.sun.jini.thread.StreamPlugThread;

public class RunTxnManager {


    private Process p1;
    private Runtime rt;
    private String  runCmd;
    private String  logDir;
	
    public RunTxnManager( String bindName,
			  String registryPort,
			  String jarTop,
			  String mahaloServer,
			  String urlTop,
			  String mahaloClient,
			  String policyFile,
			  String logDir,
			  String lookupGroups,
			  String txnOptions ) {


	this.logDir = logDir;

	runCmd = "java -jar ";
	runCmd = runCmd + "-Djava.security.policy=" + policyFile;

	if ( bindName.equals("rmi-registry") ) {
	  lookupGroups="none";
	  runCmd = runCmd + " -Dcom.sun.jini.use.registry=yes ";
	  runCmd = runCmd + " -Dcom.sun.jini.rmiregistryport=" + registryPort;
        }	   

	runCmd = runCmd +
		" -Dcom.sun.jini.mahalo.managerName=TransactionManager ";

	if ( jarTop.equals("") )
	    runCmd = runCmd + mahaloServer + " ";
	else
	    runCmd = runCmd + jarTop + File.separator + mahaloServer + " ";

	if ( urlTop.equals("") )
	    runCmd = runCmd + mahaloClient;
	else
	    runCmd = runCmd + urlTop + File.separator + mahaloClient;

	runCmd = runCmd + " " + policyFile;
	runCmd = runCmd + " " + logDir;
	runCmd = runCmd + " " + lookupGroups;
	runCmd = runCmd + " " + txnOptions;

	try {
	    FileSystem.destroy((new File(logDir)),true);
	    System.err.println("found " + logDir + " ...removing it");
	} catch (IOException e) {
	    System.err.println("Could not delete " + logDir);
	}

        try {
            Runtime rt = Runtime.getRuntime();
            System.err.println("\n\nRunning " + runCmd );

	    p1 = rt.exec(runCmd);

          StreamPlugThread.plugTogether(p1.getInputStream(),System.out);
	  StreamPlugThread.plugTogether(p1.getErrorStream(),System.err);

        } catch (IOException e) {
            System.err.println("exec error:" + e);
          }
    }

    public void destroy() {
	if (p1 != null) {
	    p1.destroy();
	    System.err.println("Killing TxnManager Service");
	} else {
	    System.err.println("Txn Manager Not Running");
	}

	try {
	    FileSystem.destroy((new File(logDir)),true);
	    System.err.println("found " + logDir + " ...removing it");
	} catch (IOException e) {
	    System.err.println("Could not delete " + logDir);
	}

    }
}



