/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */

package com.sun.jini.lease;

import net.jini.core.lease.*;


public class LeaseRenewalEvent extends java.util.EventObject {
    /**
     * The failed lease.
     *
     * @serial
     */
    private Lease lease;
    /**
     * The desired expiration of the failed lease.
     *
     * @serial
     */
    private long expiration;
    /**
     * The exception that caused the failure, if any.
     *
     * @serial
     */
    private Exception ex;

    /**
     * Construct an event.
     *
     * @param source the lease renewal manager that generates the event
     * @param lease the lease that failed to renew
     * @param expiration the desired absolute expiration for the lease
     * @param ex the exception, if any
     */
    public LeaseRenewalEvent(LeaseRenewalManager source,
			     Lease lease,
			     long expiration,
			     Exception ex) 
    {
	super(source);
	this.lease = lease;
	this.ex = ex;
    }

    private static final long serialVersionUID = -7536467680016825016L;

    /** Returns the lease that failed to renew. */
    public Lease getLease() {
	return lease;

    }


    /** Returns the desired absolute expiration for the lease. */
    public long getExpiration() {
	return expiration;
    }


    /**
     * Returns the exception, if any.  If the lease was denied, then
     * this will be a LeaseDeniedException.  If the lease expired,
     * this will be a LeaseUnknownException, a RemoteException, or null.
     */
    public Exception getException() {
	return ex;
    }
}
