/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.lease.landlord;

import net.jini.core.lease.Lease;
import net.jini.core.lease.LeaseDeniedException;

/**
 * Factory interface for classes that create Lease objects that
 * follow the Landlord protocol.
 * @see Landlord
 */
public interface LandlordLeaseFactory {
    /**
     * Create a new lease that works with landlord protocol.
     * @param cookie Object that will be passed back to 
     *               <code>Landlord.renew()</code> 
     *               and <code>Landlord.cancel()</code>
     * @param landlord The landlord to callback when the lease is 
     *                 renewed or canceled.
     * @param duration The initial duration of the lease, this must be
     *                 the initial duration of the lease,
     *                 <code>newLease()</code> may not set the lease
     *                 to have a different initial duration.
     * @exception LeaseDeniedException may be thrown if the lease can
     *            not be allocated.
     */
    public Lease newLease(Object cookie, Landlord landlord, long duration)
         throws LeaseDeniedException;
}
