/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.lease.landlord;

import net.jini.core.lease.Lease;
import net.jini.core.lease.LeaseDeniedException;
import net.jini.core.lease.UnknownLeaseException;

/**
 * Interface for classes that implement Lease grant and renewal policies. 
 */
public interface LeasePolicy {
    /**
     * Factory method that returns lease objects for the specified
     * resource. 
     *
     * @param resource The resource the lease is for. Will have its
     *                 expiration set.
     * @param requestedDuration
     *                 The length of lease the client wants.
     * @return A lease for the passed resource
     * @exception LeaseDeniedException thrown if the policy is not currently 
     *            granting leases.
     */
    public Lease leaseFor(LeasedResource resource, long requestedDuration) 
        throws LeaseDeniedException;

    /**
     * Renews the expiration of the passed resource.  
     * @param resource The resource having its lease renewed.  Will have its 
     *                 expiration set.  
     * @param requestedDuration 
     *                 The new duration the client wants
     * @return The new duration the lease should have.
     * @exception LeaseDeniedException thrown if the policy is unwilling 
     *            to renew this lease.
     * @exception UnknownLeaseException does not know of the lease associated
     *            with the passed resource.
     */
    public long renew(LeasedResource resource, long requestedDuration)
        throws LeaseDeniedException, UnknownLeaseException;

    /**
     * Returns <code>true</code> if the lease on the passed resource
     * has not expired yet.
     */
    public boolean ensureCurrent(LeasedResource resource);
}
