/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.lease.landlord;

import java.io.Serializable; 

/**
 * Leased resources must meet this interface if they are to be used
 * with <code>LeaseDurationPolicy</code> and/or
 * <code>LeaseManager</code>
 * <p>
 * @see LeaseDurationPolicy
 * @see LeaseManager 
 */
public interface LeasedResource {
    /**
     * Changes the expiration time of the leased resource.
     * @param newExpiration The new expiration time in milliseconds
     *                      since the beginning of the epoch
     */
    public void setExpiration(long newExpiration);

    /**
     * Returns the expiration time of the leased resource.
     * @return The expiration time in milliseconds since the beginning 
     *         of the epoch
     */
    public long getExpiration();

    /**
     * Returns a unique identifier that can be used by the grantor of
     * the resource to identify it in the context of a
     * <code>Landlord.renew()</code> or <code>Landlord.cancel()</code>
     * call.  In general this object will be passed between VMs using RMI
     * so care should be taken in not making this object bigger than it
     * needs to be.
     * @see Landlord#renew
     * @see Landlord#cancel
     */
    public Object getCookie();
}

