/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.mahalo;

import com.sun.jini.mahalo.log.*;

import com.sun.jini.mahalo.ParticipantHandle;
import net.jini.core.transaction.server.TransactionManager;
import net.jini.core.transaction.server.TransactionParticipant;
import java.io.Serializable;
/**
 * A <code>LogRecord</code> which encapsulates a generic
 * interaction with a participant.
 * 
 * @author Gary Holness
 */
class ParticipantModRecord implements TxnLogRecord {
    static final long serialVersionUID = 5542043673924560855L;

    private static final boolean DEBUG = false;

    /**
     * @serial
     */
    private ParticipantHandle part;

    /**
     * @serial
     */
    private int result;

    ParticipantModRecord(ParticipantHandle part, int result) {
	if (part == null)
	    throw new IllegalArgumentException("ParticipantModRecord: " +
			    "recover: non-null ParticipantHandle " +
						"recover attempted");

	this.part = part;
	this.result = result;
    }

    ParticipantHandle getPart() {
	return part;
    }

    int getResult() {
	return result;
    }

    public void recover(TxnManagerTransaction tmt)
	throws CannotRecoverException
    {
	if (tmt == null)
	    throw new NullPointerException("ParticipantModRecord: recover: " +
			    "non-null transaction must be specified");

        tmt.modifyParticipant(getPart(), getResult());

	if (getResult() == ABORTED)
	    tmt.modifyTxnState(ABORTED);

	if (DEBUG)
	    System.out.println("ParticipantModRecord: recover: recovered");
    }
}
