/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.mahalo.log;

import net.jini.admin.Administrable;

/**
 * Represents the functions performed by a log manager.
 *
 * @author Gary Holness
 */
public interface LogManager extends Administrable {

    /**
     *  Factory method which returns a Log interface which
     *  can be used to create persistent records which
     *  collectively represent a system's state.
     *
     * @param cookie identifier representing the information
     *               being logged.
     */
    ClientLog logFor(long cookie) throws LogException;


    /**
     *  Consumes the log file and re-constructs a system's
     *  state.
     */
    void recover() throws LogException;

    /**
     * Returns an object that implements whatever administration interfaces
     * are appropriate for the <code>LogManager</code>. This method
     * overrides what is defined in the supertype.
     *
     * @return an object that implements whatever administration interfaces
     *         are appropriate for the particular service.
     *
     * @see net.jini.admin.Administrable
     */
    Object getAdmin();
}
