/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.mahout;

import java.util.Properties;

/**
 * Simple implementation of PersistentServiceDesc.  Its configuration
 * is fixed at creation.  Extends <code>PersistentServiceDesc</code>
 * with an additional method to return a lookup group list.
 */
public class BasicServiceDesc implements PersistentServiceDesc
{
    final private String path;
    final private String classpath;
    final private String codebase;
    final private String policy;
    final private String jvmPath;
    final private String[] jvmArgs;
    final private Properties props;
    final private String[] groups;

    /**
     * Create a BasicServiceDesc that will return the given values
     * for getClassPath(), getCodebase(), getPolicyPath(), 
     * getPersistentsPath(), getGroups(), getJVMPath(), getJVMOptions(),
     * getProperties()
     */
    public BasicServiceDesc(String classpath, String codebase, String policy,
        String path, String[] groups, String jvmPath, String[] jvmArgs,
	Properties props)
    {
	this.classpath = classpath;
	this.codebase = codebase;
	this.policy = policy;
	this.path = path;
	this.groups = groups;
	this.jvmPath = jvmPath;
	this.jvmArgs = jvmArgs;
	this.props = props;
    }

    // purposefully inherit doc comment from supertype
    public String getPersistentsPath() {return path;}

    // purposefully inherit doc comment from supertype
    public String getClassPath() {return classpath;}

    // purposefully inherit doc comment from supertype
    public String getCodebase() {return codebase;}

    // purposefully inherit doc comment from supertype
    public String getPolicyPath() {return policy;}

    // purposefully inherit doc comment from supertype
    public Properties getProperties() {return props;}

    // purposefully inherit doc comment from supertype
    public String getJVMPath() {return jvmPath;}

    // purposefully inherit doc comment from supertype
    public String[] getJVMOptions() {return jvmArgs;}
    
    /**
     * Lookup groups list, set when object was created.
     */
    public String[] getGroups() {return groups;}
}
