/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.mahout;

import java.util.Properties;

/**
 * Data required by a persistent service in the Jini system to set
 * itself up. If any method returns invalid data the service setup 
 * code will throw "IllegalArgumentException"
 */
public interface PersistentServiceDesc {
    /**
     * Absolute path to a directory where the service can persist its
     * data.  If the directory exists the builder of the
     * <code>PersistentServiceDesc</code> should ensure no service is
     * using it.  Not all services can successfully use existing log
     * files.
     */
    public String getPersistentsPath();
    
    /**
     * A list of file system paths separated by
     * <code>File.pathSeparator</code> This is where the service will
     * load its classes from
     */
    public String getClassPath();

    /**
     * A space separated list of URLs.  Classes loaded from the classpath
     * will be annotated with these URLs.
     */
    public String getCodebase();

    /**
     * Location of the security policy file.
     */
    public String getPolicyPath();

    /**
     * Properties for the VM the service will be run in.  May be
     * <code>null</code>
     */
    public Properties getProperties();

    /**
     * The name of the java executable, including the full path, or
     * null, meaning "use rmid's default". The named program must be
     * able to accept multiple -Dpropname=value options (as documented
     * for the "java" tool) 
     */
    public String getJVMPath();

    /**
     * Command line options for the VM in which the service will be
     * run.  May be <code>null</code>, which has the same affect as an
     * empty array.
     */
    public String[] getJVMOptions();
}

