/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.mahout;

import java.io.IOException;

/**
 * Administrative interface for controlling whether or not a service will 
 * bind itself into the RMI registry and how.
 */
public interface RegistryAdmin {
    /**
     * Enable binding of the service into the RMI registry. If the
     * service is persistent it should also rebind itself into
     * registry when restarted.
     * <p>
     * This method will typically spawn a separate thread to do the
     * actual work asynchronously, so a successful return from this
     * method usually does not mean the service has finished the
     * process of binding itself RMI registry, just that it will in
     * the future if an appropriate registry exists.
     * <p>
     *
     * @param name The name bind itself under
     * @param port The port to look for the registry on.
     * @exception IllegalArgumentException if name is <code>null</code>
     * @exception IllegalStateException if binding into 
     *     RMI registry has already been enabled.  */
     public void enableRegistryBinding(String name, int port) 
	throws IOException;
}
