/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.mahout.binder;

import java.io.IOException;
import net.jini.admin.JoinAdmin;

/**
 * Provides an abstraction for placing a service in a directory.
 * Different binders bind the service into different types of
 * directories (i.e. RMI registry v. Jini lookup).
 *
 * @see BinderSetup
 * @author John W.F. McClain 
 */
public interface Binder {
    /**
     * Return an object that implements DirectoryAdmin.  This object
     * is should be used by the services admin to implement the
     * <code>JoinAdmin</code> and <code>RegistryAdmin</code> interfaces.
     * @see net.jini.admin.JoinAdmin
     * @see com.sun.jini.mahout.RegistryAdmin
     */
    public DirectoryAdmin getDirectoryAdmin();

    /**
     * Has the binder register the service with the appropriate
     * directory service.  Only needs to be called once, though
     * calling it more than once is safe even if an exception is
     * thrown by a previous call
     */
    public void advertise() throws IOException;

    /**
     * Unregister with the directory service and unregister any
     * activatable objects.
     */
    public void destroy();
}
