/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.mahout.binder;

import java.io.Serializable;
import java.io.IOException;
import java.rmi.RemoteException;

/**
 * An abstraction of the processes of setting up a <code>Binder</code>
 * for an activatable service.  The intention is to use one
 * <code>BinderSetup</code> to setup one <code>Binder</code>. The
 * interface is inteded to be used when the service is initially setting
 * itself up, not when it is activated or running.
 *
 * Setting up a <code>Binder</code> for an activatable service involves
 * 4 steeps.
 *
 * <DL>
 * <DT> Construct a concrete instance of a <code>BinderSetup</code> object,
 * this usually requires an <code>ActivationGroup</code> to be
 * available and information about where to place the binder's
 * persistent state.
 *
 * <DT> Call <code>getBinderFactory()</code> method of the
 * <code>BinderSetup</code>.  This yields a <code>BinderFactory</code>
 * object that should be stored in the services persistent state and
 * used when the service is activated.
 *
 * <DT> Call <code>setService()</code> method of the
 * <code>BinderSetup</code>, this will complete the setup process and
 * bind the service into the appropriate directory.
 * 
 * <DT> When the service is activated it should retrieve the
 * <code>BinderFactory</code> it stored in step two and invoke its
 * <code>get()</code> method to obtain the <code>Binder</code>. At this
 * point the binder can be used normally, though there is no
 * requirement to call the <code>Binder</code>'s
 * <code>advertise()</code> method.
 * </DL>
 *
 * @see Binder
 * @see BinderFactory
 * @author John W.F. McClain 
 */
public interface BinderSetup {
    /**
     * Get object that can be stored and unpacked during activation to
     * server as a binder.  This method should only be called once on 
     * a given <code>BinderSetup</code>, if called more than once the
     * results are undefined.
     */
    public BinderFactory getBinderFactory();

    /**
     * Set the service that should be placed in the directory, this
     * will register with the directory service.  This method should
     * only be called once on a given <code>BinderSetup</code>, if
     * called more than once the results are underfined.
     *
     * @param service The service to be placed in the directory.  Any
     * remote objects that are embedded in it and/or itself must have been
     * exported.  
     */
    public void setService(Object service) throws IOException, RemoteException;
}

