/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.mahout.binder;

import java.io.IOException;
import net.jini.core.discovery.LookupLocator;
import net.jini.core.lookup.ServiceID;
import net.jini.core.entry.Entry;
import com.sun.jini.lookup.JoinManager;


/**
 * Implementation of JoinAdminState that does not persist its data.  Used by
 * RemoteJoinAdminImpl when it is working with a non-activatable service.
 */
class TransientJoinAdminState implements JoinAdminState {
    /** The service RemoteJoinAdminImpl is working for */
    private Object  service;

    /** 
     * The list of attributes we were passed in at construction, used only to 
     * initialize the <code>JoinManager</code>.
     */
    private Entry[] attributes;

    /** 
     * <code>JoinManager</code> we created for the
     * <code>RemoteJoinAdminImpl</code>. 
     */
    private JoinManager mgr;

    /**
     * True if binding into the RMI registry is enabled.
     */
    private boolean registryEnabled = false;

    /** 
     * Value of port argument of
     * <code>recordRegistryBindingEnable()</code> call. Valid if
     * <code>registryEnabled</code> is true.  
     */
    private int port;

    /** 
     * Value of name argument of
     * <code>recordRegistryBindingEnable()</code> call. Valid if
     * <code>registryEnabled</code> is true.  
     */
    private String name;

    /**
     * Create a <code>TransientJoinAdminState</code> object.
     * @param service Service that we are binding into the jini
     *                lookup/RMI registry 
     * @param attributes Initial set of lookup attributes.
     */
    TransientJoinAdminState(Object service, Entry[] attributes) {
	this.service = service;
	this.attributes = attributes;
    }

    // Inherit doc comment from super interface
    public JoinManager startNewJoinManager() throws IOException {
	return new JoinManager(service, attributes, new String[0], 
			       new LookupLocator[0], null, null);
    }

    // Inherit doc comment from super interface
    public Object getService() {return service;}

    // Inherit doc comment from super interface
    public ServiceID getServiceID() {return null;}

    // Inherit doc comment from super interface
    public void updateLookupLocators() {}

    // Inherit doc comment from super interface
    public void updateGroups() {}

    // Inherit doc comment from super interface
    public void updateAttributes() {}

    // Inherit doc comment from super interface
    public boolean destroy() {return true;}


    // Inherit doc comment from super interface
    public void recordRegistryBindingEnable(String name, int port) {
	if (isRegistryBindingEnabled())
	    throw new 
		IllegalStateException("Registry binding already enabled");
	registryEnabled = true;
	this.port = port;
	this.name = name;
    }

    // Inherit doc comment from super interface
    public boolean isRegistryBindingEnabled() {
	return registryEnabled;
    }

    // Inherit doc comment from super interface
    public int getPort() {
	if (!isRegistryBindingEnabled())
	    throw new IllegalStateException("Registry binding not enabled");
	return port;
    }

    // Inherit doc comment from super interface
    public String getName() {
	if (!isRegistryBindingEnabled())
	    throw new IllegalStateException("Registry binding not enabled");
	return name;
    }
}


