/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.reggie;

import java.rmi.server.RMIClassLoader;
import java.io.IOException;

/** An EntryClass annotated with a codebase. */
class EntryClassBase implements java.io.Serializable {
    /**
     * The EntryClass.
     *
     * @serial
     */
    public final EntryClass eclass;
    /**
     * The codebase.
     *
     * @serial
     */
    public String codebase;

    private static final long serialVersionUID = 359458147508924971L;

    /** Simple constructor */
    public EntryClassBase(EntryClass eclass, String codebase) {
	this.eclass = eclass;
	this.codebase = codebase;
    }

    /** Sets the codebase to the codebase of the given class. */
    public void setCodebase(Class cls) {
	codebase = RMIClassLoader.getClassAnnotation(cls);
    }

    /**
     * Converts an array of EntryClassBase to an array of Class.  If a
     * class cannot be loaded, it is left as null.
     */
    public static Class[] toClass(EntryClassBase[] eclasses)
    {
	Class[] classes = null;
	if (eclasses != null) {
	    classes = new Class[eclasses.length];
	    for (int i = eclasses.length; --i >= 0; ) {
		try {
		    EntryClassBase eclass = eclasses[i];
		    classes[i] = eclass.eclass.toClass(eclass.codebase);
		} catch (Exception e) {
		    RegistrarProxy.printException(e);
		}
	    }
	}
	return classes;
    }
}
