/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.reggie;

import net.jini.core.lease.*;

/** The base class for lease proxies. */
abstract class RegistrarLease extends com.sun.jini.lease.AbstractLease {

    private static final long serialVersionUID = 1286538697644640310L;

    /**
     * The registrar.
     *
     * @serial
     */
    protected final Registrar server;
    /**
     * The internal lease id.
     *
     * @serial
     */
    protected final long leaseID;

    /** Simple constructor. */
    protected RegistrarLease(Registrar server, long leaseID, long expiration) {
	super(expiration);
	this.server = server;
	this.leaseID = leaseID;
    }

    /** Create a lease map. */
    public LeaseMap createLeaseMap(long duration) {
	return new RegistrarLeaseMap(this, duration);
    }

    /**
     * Two leases can be batched if they are both RegistrarLeases and
     * have the same server.
     */
    public boolean canBatch(Lease lease) {
	return (lease instanceof RegistrarLease &&
		server.equals(((RegistrarLease)lease).server));
    }

    /** Return the registrar. */
    Registrar getRegistrar() {
	return server;
    }

    /** Returns the lease ID */
    long getLeaseID() {
	return leaseID;
    }

    /** Returns the service ID, or the event ID as a Long */
    abstract Object getRegID();

    /** Set the expiration. */
    void setExpiration(long expiration) {
	this.expiration = expiration;
    }
}
