/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.reggie;

import net.jini.core.lookup.*;
import java.rmi.RemoteException;

/**
 * A Template contains the fields of a ServiceTemplate packaged up for
 * transmission between client-side proxies and the registrar server.
 * Instances are never visible to clients, they are private to the
 * communication between the proxies and the server.
 * <p>
 * This class only has a bare minimum of methods, to minimize
 * the amount of code downloaded into clients.
 */
class Template implements java.io.Serializable {

    private static final long serialVersionUID = 5719167991752760177L;

    /**
     * ServiceTemplate.serviceID
     *
     * @serial
     */
    public ServiceID serviceID;
    /**
     * ServiceTemplate.serviceTypes converted to ServiceTypes
     *
     * @serial
     */
    public ServiceType[] serviceTypes;
    /**
     * ServiceTemplate.attributeSetTemplates converted to EntryReps
     *
     * @serial
     */
    public EntryRep[] attributeSetTemplates;

    /**
     * Converts a ServiceTemplate to a Template.  Any exception that results
     * is bundled up into a MarshalException.
     */
    public Template(ServiceTemplate tmpl) throws RemoteException {
	serviceID = tmpl.serviceID;
	serviceTypes = ClassMapper.toServiceType(tmpl.serviceTypes);
	attributeSetTemplates =
	    EntryRep.toEntryRep(tmpl.attributeSetTemplates, false);
    }
}
