/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.discovery;

import java.net.InetAddress;
import java.net.UnknownHostException;

/**
 * A holder class for constants that pertain to the unicast and
 * multicast discovery protocols.
 * 
 * @author Bryan O'Sullivan
 */
public class Constants {
    /**
     * The address of the multicast group over which the multicast
     * request protocol takes place.
     */
    private static InetAddress requestAddress = null;

    /**
     * The address of the multicast group over which the multicast
     * announcement protocol takes place.
     */
    private static InetAddress announcementAddress = null;

    /**
     * The port for both unicast and multicast boot requests.
     */
    public static final short discoveryPort = 4160;

    /**
     * This class cannot be instantiated.
     */
    private Constants() {}
  
    /**
     * Return the address of the multicast group over which the
     * multicast request protocol takes place.
     */
    public static final InetAddress getRequestAddress()
	throws UnknownHostException
    {
	if (requestAddress == null)
	    requestAddress = InetAddress.getByName("224.0.1.85");
	return requestAddress;
    }
  

    /**
     * Return the address of the multicast group over which the
     * multicast announcement protocol takes place.
     */
    public static final InetAddress getAnnouncementAddress()
	throws UnknownHostException
    {
	if (announcementAddress == null)
	    announcementAddress = InetAddress.getByName("224.0.1.84");
	return announcementAddress;
    }
}
