/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.discovery;

import java.util.EventObject;
import net.jini.core.lookup.ServiceRegistrar;

/**
 * Event object passed (via the DiscoveryListener interface) to indicate to
 * interested parties that one or more ServiceRegistrar
 * objects have been discovered or discarded by a LookupDiscovery
 * object.
 *
 * @see LookupDiscovery
 * @see DiscoveryListener
 * @see net.jini.core.lookup.ServiceRegistrar
 * @author Bryan O'Sullivan
 */
public class DiscoveryEvent extends EventObject {
    private static final long serialVersionUID = 5280303374696501479L;

    /**
     * The registrars with which this event is associated.
     *
     * @serial
     */
    protected ServiceRegistrar[] regs;

    /**
     * Construct a new DiscoveryEvent object, with the given source
     * and set of registrars.  The set of registrars should not be
     * empty.
     *
     * @param source the source of this event
     * @param regs the registrars to which this event applies
     */
    public DiscoveryEvent(Object source, ServiceRegistrar[] regs) {
	super(source);
	this.regs = regs;
    }

    /**
     * Return the set of registrars to which this event applies.
     * The same array is returned on every call; a copy is not made.
     */
    public ServiceRegistrar[] getRegistrars() {
	return regs;
    }
}
