/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.discovery;

import java.util.EventListener;

/**
 * This interface must be implemented by parties that wish to obtain
 * notifications from a LookupDiscovery object.
 *
 * @see LookupDiscovery
 * @author Bryan O'Sullivan
 */
public interface DiscoveryListener extends EventListener {
    /**
     * Called when one or more lookup service registrars has been discovered.
     * The method should return quickly; e.g., it should not make remote
     * calls.
     *
     * @param e the event that describes the discovered registrars
     */
    void discovered(DiscoveryEvent e);

    /**
     * Called when one or more lookup service registrars has been discarded.
     * The method should return quickly; e.g., it should not make remote
     * calls.
     *
     * @param e the event that describes the discarded registrars
     */
    void discarded(DiscoveryEvent e);
}
