/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.discovery;

import java.io.DataInputStream;
import java.io.InputStream;
import java.io.IOException;

/**
 * Encapsulate the details of unmarshaling an incoming unicast
 * request.  This class has no public methods because the request
 * portion of the current version of the unicast discovery protocol
 * does nothing other than indicate its version.
 *
 * @see OutgoingUnicastRequest
 * @author Bryan O'Sullivan
 */
public class IncomingUnicastRequest {
    /**
     * The current version of the unicast discovery protocol.
     */
    protected int protoVersion = 1;

    /**
     * Construct a new object, initialized by unmarshaling the
     * contents of an input stream.
     *
     * @param str the stream from which to unmarshal a request
     * @exception IOException the request could not be unmarshaled
     */
    public IncomingUnicastRequest(InputStream str) throws IOException {
	DataInputStream dstr = new DataInputStream(str);
	int proto = dstr.readInt();
	if (proto != protoVersion)
	    throw new IOException("unsupported protocol version: " + proto);
    }
}
