/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.discovery;

import java.io.ObjectOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.rmi.MarshalledObject;
import net.jini.core.lookup.ServiceRegistrar;

/**
 * Encapsulate the details of marshaling a unicast response.
 *
 * @see IncomingUnicastResponse
 * @author Bryan O'Sullivan
 */
public class OutgoingUnicastResponse {
    /**
     * The current version of the unicast discovery protocol.
     */
    protected int protoVersion = 1;

    /**
     * Marshal a unicast response to the given output stream.  The
     * stream is flushed afterwards.
     *
     * @param str the stream to marshal to
     * @param reg the registrar object to marshal
     * @param groups the groups in which the registrar is currently a
     * member
     * @exception IOException a problem occurred during marshaling
     */
    public static void marshal(OutputStream str,
			       ServiceRegistrar reg,
			       String[] groups)
	throws IOException
    {
	ObjectOutputStream ostr = new ObjectOutputStream(str);
	ostr.writeObject(new MarshalledObject(reg));
	ostr.writeInt(groups.length);
	for (int i = 0; i < groups.length; i++) {
	    ostr.writeUTF(groups[i]);
	}
	ostr.flush();
    }
}
