/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */

package net.jini.lookup;

import java.rmi.RemoteException;
import java.io.IOException;

/**
 * Methods for controlling which groups a lookup service is a member of,
 * and for controlling which TCP port a lookup service uses for its
 * lookup locator.  Lookup services that implement the Administrable
 * interface should return an admin object that implements this interface.
 */
public interface DiscoveryAdmin {

    /**
     * Get the list of groups that the lookup service is a member of.  An
     * empty array means the lookup service is a member of no groups
     * (as opposed to "all" groups).
     *
     * @return a String array of groups that the lookup service is a 
     *         member of.
     * @throws java.rmi.RemoteException
     */
    String[] getMemberGroups() throws RemoteException;

    /**
     * Add new groups for the lookup service to be a member of.
     *
     * @param groups groups to be a member of
     * @throws java.rmi.RemoteException
     */
    void addMemberGroups(String[] groups) throws RemoteException;

    /**
     * Remove groups from list that the lookup service is a member of.
     *
     * @param groups groups to stop being a member of
     * @throws java.rmi.RemoteException
     */
    void removeMemberGroups(String[] groups) throws RemoteException;

    /**
     * Replace the list of groups to be a member of with a new list.
     *
     * @param groups groups to be a member of
     * @throws java.rmi.RemoteException
     */
    void setMemberGroups(String[] groups) throws RemoteException;

    /**
     * Get the port number on which the lookup service listens for
     * unicast discovery queries.
     *
     * @return an int representing the port number on which the lookup 
     *         service listens for unicast discovery queries.
     * 
     * @throws java.rmi.RemoteException
     */
    public int getUnicastPort() throws RemoteException;

    /**
     * Set the port number on which the lookup service listens for
     * unicast discovery queries.  A port of zero means the lookup
     * service should first try to listen on the standard unicast
     * discovery port, but if that fails, then it should listen on
     * an arbitrary port.
     *
     * @param port the port number
     * @throws java.io.IOException
     * @throws java.rmi.RemoteException
     */
    public void setUnicastPort(int port) throws IOException, RemoteException;
}
