/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.lookup.entry;

import java.io.Serializable;
import net.jini.core.entry.Entry;

/**
 * A JavaBeans(TM) component that encapsulates an Address object.
 *
 * @see Address
 * @see Location
 * @see LocationBean
 * @author Bryan O'Sullivan
 */
public class AddressBean implements EntryBean, Serializable {
    private static final long serialVersionUID = 4491500432084550577L;

    /**
     * The Address object associated with this JavaBeans component.
     *
     * @serial
     */
    protected Address assoc;

    /**
     * Construct an instance of this JavaBeans component that is 
     * linked to a new Address object.
     */
    public AddressBean() {
	assoc = new Address();
    }

    /**
     * Make a link to an Entry object.
     *
     * @param e the Entry object to link to
     * @exception java.lang.ClassCastException the Entry is not of the
     * correct type for this JavaBeans component
     */
    public void makeLink(Entry e) {
	assoc = (Address) e;
    }

    /**
     * Return the Entry linked to by this JavaBeans component.
     */
    public Entry followLink() {
	return assoc;
    }

    /**
     * Return the value of the street field in the Address object linked to by
     * this JavaBeans component.
     */
    public String getStreet() {
	return assoc.street;
    }

    /**
     * Set the value of the street field in the Address object linked to by
     * this JavaBeans component.
     */
    public void setStreet(String x) {
	assoc.street = x;
    }

    /**
     * Return the value of the organization field in the Address object linked
     * to by this JavaBeans component.
     */
    public String getOrganization() {
	return assoc.organization;
    }

    /**
     * Set the value of the organization field in the Address object linked to
     * by this JavaBeans component.
     */
    public void setOrganization(String x) {
	assoc.organization = x;
    }
    
    /**
     * Return the value of the organizationalUnit field in the Address object
     * linked to by this JavaBeans component.
     */
    public String getOrganizationalUnit() {
	return assoc.organizationalUnit;
    }

    /**
     * Set the value of the organizationalUnit field in the Address object
     * linked to by this JavaBeans component.
     */
    public void setOrganizationalUnit(String x) {
	assoc.organizationalUnit = x;
    }
    
    /**
     * Return the value of the locality field in the Address object linked
     * to by this JavaBeans component.
     */
    public String getLocality() {
	return assoc.locality;
    }

    /**
     * Set the value of the locality field in the Address object linked to
     * by this JavaBeans component.
     */
    public void setLocality(String x) {
	assoc.locality = x;
    }

    /**
     * Return the value of the stateOrProvince field in the Address object
     * linked to by this JavaBeans component.
     */
    public String getStateOrProvince() {
	return assoc.stateOrProvince;
    }

    /**
     * Set the value of the stateOrProvince field in the Address object
     * linked to by this JavaBeans component.
     */
    public void setStateOrProvince(String x) {
	assoc.stateOrProvince = x;
    }

    /**
     * Return the value of the postalCode field in the Address object linked
     * to by this JavaBeans component.
     */
    public String getPostalCode() {
	return assoc.postalCode;
    }

    /**
     * Set the value of the postalCode field in the Address object linked to
     * by this JavaBeans component.
     */
    public void setPostalCode(String x) {
	assoc.postalCode = x;
    }

    /**
     * Return the value of the country field in the Address object linked to
     * by this JavaBeans component.
     */
    public String getCountry() {
	return assoc.country;
    }

    /**
     * Set the value of the country field in the Address object linked to by
     * this JavaBeans component.
     */
    public void setCountry(String x) {
	assoc.country = x;
    }
}
