/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.lookup.entry;

import net.jini.entry.AbstractEntry;

/**
 * The location of the physical component of a service.  This is
 * distinct from the Address class in that it can be used alone in a
 * small, local organization.
 *
 * @see Address
 * @see LocationBean
 * @author Bryan O'Sullivan
 */
public class Location extends AbstractEntry {
    private static final long serialVersionUID = -3275276677967431315L;

    /**
     * Construct an empty instance of this class.
     */
    public Location() {
    }

    /**
     * Construct an instance of this class, with all fields
     * initialized appropriately.
     */
    public Location(String floor, String room, String building) {
	this.floor = floor;
	this.room = room;
	this.building = building;
    }

    /**
     * A floor designation.  For example, "2".
     *
     * @serial
     */
    public String floor;

    /**
     * A room or cube number.  For example, "B250".
     *
     * @serial
     */
    public String room;

    /**
     * A building name or code.  For example, "SUN04".
     *
     * @serial
     */
    public String building;
}
