/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.lookup.entry;

import java.io.Serializable;
import net.jini.core.entry.Entry;

/**
 * A JavaBeans(TM) component that encapsulates a ServiceInfo object.
 *
 * @see ServiceInfo
 * @author Bryan O'Sullivan
 */
public class ServiceInfoBean implements EntryBean, Serializable {
    private static final long serialVersionUID = 8352546663361067804L;

    /**
     * The ServiceInfo object associated with this JavaBeans component.
     *
     * @serial
     */
    protected ServiceInfo assoc;

    /**
     * Construct a new JavaBeans component, linked to a new empty 
     * ServiceInfo object.
     */
    public ServiceInfoBean() {
	assoc = new ServiceInfo();
    }

    /**
     * Make a link to an Entry object.
     *
     * @param e the Entry object to link to
     * @exception java.lang.ClassCastException the Entry is not of the
     * correct type for this JavaBeans component
     */
    public void makeLink(Entry e) {
	assoc = (ServiceInfo) e;
    }

    /**
     * Return the Entry linked to by this JavaBeans component.
     */
    public Entry followLink() {
	return assoc;
    }

    /**
     * Return the value of the name field in the ServiceInfo object linked
     * to by this JavaBeans component.
     */
    public String getName() {
	return assoc.name;
    }

    /**
     * Set the value of the name field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public void setName(String x) {
	assoc.name = x;
    }

    /**
     * Return the value of the manufacturer field in the ServiceInfo
     * object linked to by this JavaBeans component.
     */
    public String getManufacturer() {
	return assoc.manufacturer;
    }

    /**
     * Set the value of the manufacturer field in the ServiceInfo
     * object linked to by this JavaBeans component.
     */
    public void setManufacturer(String x) {
	assoc.manufacturer = x;
    }

    /**
     * Return the value of the vendor field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public String getVendor() {
	return assoc.vendor;
    }

    /**
     * Set the value of the vendor field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public void setVendor(String x) {
	assoc.vendor = x;
    }

    /**
     * Return the value of the version field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public String getVersion() {
	return assoc.version;
    }

    /**
     * Set the value of the version field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public void setVersion(String x) {
	assoc.version = x;
    }

    /**
     * Return the value of the model field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public String getModel() {
	return assoc.model;
    }

    /**
     * Set the value of the model field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public void setModel(String x) {
	assoc.model = x;
    }

    /**
     * Return the value of the serialNumber field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public String getSerialNumber() {
	return assoc.serialNumber;
    }

    /**
     * Set the value of the serialNumber field in the ServiceInfo object
     * linked to by this JavaBeans component.
     */
    public void setSerialNumber(String x) {
	assoc.serialNumber = x;
    }
}
