/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package net.jini.lookup.entry;

import java.io.Serializable;

/**
 * Information pertaining to the severity of a Status object.
 *
 * @see Status
 * @author Bryan O'Sullivan
 */
public class StatusType implements Serializable {
    private static final long serialVersionUID = -8268735508512712203L;

    /** @serial */
    private final int type;

    private StatusType(int t) {
	type = t;
    }

    /**
     * An error has occurred that is preventing a service from
     * operating correctly.
     */
    public static final StatusType ERROR = new StatusType(1);

    /**
     * A problem merits attention, but is not impeding the operation
     * of the service.
     */
    public static final StatusType WARNING = new StatusType(2);

    /**
     * An unusual event is occurring, but the event is not necessarily
     * a problem.
     */
    public static final StatusType NOTICE = new StatusType(3);

    /**
     * A noteworthy event is occurring during the normal operation of
     * a service.
     */
    public static final StatusType NORMAL = new StatusType(4);
}
