/*
 * Copyright (c) 1999 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * The contents of this file are subject to the Sun Community Source License
 * Jini(TM) Technology Core Platform, v.1.0 (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of
 * the License at http://java.sun.com/products/jini. Software distributed
 * under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
 * ANY KIND, either express or implied.  See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * CopyrightVersion v1.0_Jini
 */
package com.sun.jini.tool;

import java.io.File;
import java.io.Serializable;
import java.rmi.Remote;

public class CheckSer {

    public static void main(String[] args) {
	if (args.length == 0)
	    args = new String[]{"/vob/jive/classes"};
	for (int i = 0; i < args.length; i++) {
	    check(args[i], args[i].length() + 1);
	}
    }

    public static void check(String dir, int strip) {
	String[] files = new File(dir).list();
	if (files == null) {
	    System.out.println("no such directory: " + dir);
	    return;
	}
	for (int i = 0; i < files.length; i++) {
	    String file = dir + File.separatorChar + files[i];
	    if (file.endsWith(".class"))
		checkClass(file, strip);
	    else if (new File(file).isDirectory())
		check(file, strip);
	}
    }

    public static void checkClass(String file, int strip) {
	file = file.substring(strip, file.length() - 6);
	file = file.replace(File.separatorChar, '.');
	try {
	    Class c = Class.forName(file);
	    if (c.isInterface() ||
		!Serializable.class.isAssignableFrom(c) ||
		Remote.class.isAssignableFrom(c))
		return;
	    c.getDeclaredField("serialVersionUID");
	} catch (ClassNotFoundException e) {
	    System.out.println("failed to load: " + file);
	} catch (NoClassDefFoundError e) {
	    System.out.println("failed to load: " + file);
	} catch (NoSuchFieldException e) {
	    System.out.println(file);
	}
    }
}
